Feat

Struct Feat 

pub struct Feat<'a> {
    data: FontData<'a>,
}
The feature name table.

Fields

data: FontData<'a>

Implementations

Source

impl<'a> Feat<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> MajorMinor

Version number of the feature name table (0x00010000 for the current version).

pub fn feature_name_count(&self) -> u16

The number of entries in the feature name array.

pub fn names(&self) -> &'a [FeatureName]

The feature name array, sorted by feature type.

pub fn version_byte_range(&self) -> Range<usize>

pub fn feature_name_count_byte_range(&self) -> Range<usize>

pub fn _reserved1_byte_range(&self) -> Range<usize>

pub fn _reserved2_byte_range(&self) -> Range<usize>

pub fn names_byte_range(&self) -> Range<usize>

Source

impl Feat<'_>

pub fn find(&self, feature: u16) -> Option<FeatureName>

Returns the name for the given feature code.